@@ -21,7 +21,8 @@ class ProfileProperty(object):
                  updated=None,
                  created=None,
                  ttl=None,
-                 expire_at=None):
+                 expire_at=None,
+                 update_condition_redis=None):
 
         self.name = name
         self.value = self.validate(value) if not value is None else value
@@ -35,6 +36,8 @@ class ProfileProperty(object):
         else:
             self.expire_at = expire_at or None
 
+        self.update_condition_redis = update_condition_redis
+
     def __repr__(self):
 
         return str(self.__class__.__name__) + '(`{}`:{})'.format(self.name, self.value)
@@ -142,6 +145,8 @@ class ProfileProperty(object):
             d.update({'value': self.value_to_redis(self.value)})
         if self.expire_at:
             d.update({'expire_at': self.expire_at.timestamp()})
+        if not self.update_condition_redis is None:
+            d.update({'update_condition': self.update_condition_redis})
         if self.extra_redis_args:
             d.update(self.extra_redis_args)
         return d
