@@ -131,7 +131,8 @@ class Profile(object):
                                    value=obj.get('value'),
                                    ttl=obj.get('ttl'),
                                    updated=updated,
-                                   created=created)
+                                   created=created,
+                                   update_condition_redis=obj.get('update_condition_redis'))
             for obj in data
         }
 
